@@ -74,6 +74,22 @@ void
 callbacks_quit_activate                       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+callbacks_fullscreen_toggled                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+callbacks_show_toolbar_toggled                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+callbacks_show_sidepane_toggled               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+callbacks_toggle_layer_visibility_activate                (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 callbacks_zoom_in_activate                    (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -152,6 +168,12 @@ callbacks_clear_messages_button_clicked  (GtkButton *button, gpointer   user_dat
 void
 callbacks_statusbar_unit_combo_box_changed (GtkComboBox *widget, gpointer user_data);
 
+void
+callbacks_viewmenu_units_changed (GtkCheckMenuItem *widget, gpointer user_data);
+
+void
+callbacks_viewmenu_rendertype_changed (GtkCheckMenuItem *widget, gpointer user_data);
+
 void
 callbacks_sidepane_render_type_combo_box_changed (GtkComboBox *widget, gpointer user_data);
 
@@ -175,6 +197,10 @@ callbacks_update_statusbar_measured_distance (gdouble dx, gdouble dy);
 void
 callbacks_update_layer_tree (void);
 
+gboolean
+callbacks_layer_tree_key_press (GtkWidget *widget, GdkEventKey *event,
+                                   gpointer user_data);
+
 gboolean
 callbacks_layer_tree_button_press (GtkWidget *widget, GdkEventButton *event,
                                    gpointer user_data);
@@ -183,9 +209,13 @@ void callbacks_add_layer_button_clicked  (GtkButton *button, gpointer   user_dat
 
 void callbacks_remove_layer_button_clicked  (GtkButton *button, gpointer   user_data);
 
+void callbacks_move_layer_down_menu_activate (GtkMenuItem *menuitem, gpointer user_data);
+
 void callbacks_move_layer_down_button_clicked  (GtkButton *button, gpointer   user_data);
 
-void callbacks_move_layer_up_clicked  (GtkButton *button, gpointer   user_data);
+void callbacks_move_layer_up_menu_activate (GtkMenuItem *menuitem, gpointer user_data);
+
+void callbacks_move_layer_up_button_clicked  (GtkButton *button, gpointer   user_data);
 
 void callbacks_layer_tree_row_inserted (GtkTreeModel *tree_model, GtkTreePath  *path,
                               GtkTreeIter  *oIter, gpointer      user_data);
