@@ -75,12 +75,6 @@ static void calc_cirseg_sq(struct gerbv_net *net, int cw,
 static void calc_cirseg_mq(struct gerbv_net *net, int cw, 
 			   double delta_cp_x, double delta_cp_y);
 
-static void
-gerber_update_min_and_max(gerbv_render_size_t *boundingBox,
-			  gdouble x, gdouble y, gdouble apertureSizeX1,
-			  gdouble apertureSizeX2,gdouble apertureSizeY1,
-			  gdouble apertureSizeY2);
-
 
 static void gerber_update_any_running_knockout_measurements(gerbv_image_t *image);
 
@@ -192,6 +186,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    if (image->format && image->format->omit_zeros == GERBV_OMIT_ZEROS_TRAILING) {
 		
 		switch ((image->format->x_int + image->format->x_dec) - len) {
+		case 7:
+		    coord *= 10;
+		case 6:
+		    coord *= 10;
 		case 5:
 		    coord *= 10;
 		case 4:
@@ -220,6 +218,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    if (image->format && image->format->omit_zeros == GERBV_OMIT_ZEROS_TRAILING) {
 
 		switch ((image->format->y_int + image->format->y_dec) - len) {
+		case 7:
+		    coord *= 10;
+		case 6:
+		    coord *= 10;
 		case 5:
 		    coord *= 10;
 		case 4:
@@ -248,6 +250,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    if (image->format && image->format->omit_zeros == GERBV_OMIT_ZEROS_TRAILING) {
 
 		switch ((image->format->y_int + image->format->y_dec) - len) {
+		case 7:
+		    coord *= 10;
+		case 6:
+		    coord *= 10;
 		case 5:
 		    coord *= 10;
 		case 4:
@@ -273,6 +279,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    if (image->format && image->format->omit_zeros == GERBV_OMIT_ZEROS_TRAILING) {
 
 		switch ((image->format->y_int + image->format->y_dec) - len) {
+		case 7:
+		    coord *= 10;
+		case 6:
+		    coord *= 10;
 		case 5:
 		    coord *= 10;
 		case 4:
@@ -295,7 +305,10 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 	    dprintf("... Found %% code\n");
 	    while (1) {
 	    	parse_rs274x(levelOfRecursion, fd, image, state, curr_net, stats, directoryPath);
+	    	/* advance past any whitespace here */
 		int c = gerb_fgetc(fd);
+		while ((c == '\n')||(c == '\r')||(c == ' ')||(c == '\t')||(c == 0))
+			c = gerb_fgetc(fd);
 		if(c == EOF || c == '%')
 		    break;
 		// loop again to catch multiple blocks on the same line (separated by * char)
@@ -672,14 +685,8 @@ gerber_parse_file_segment (gint levelOfRecursion, gerbv_image_t *image,
 					     
 		}
 		/* update the info bounding box with this latest bounding box */
-		if (boundingBox.left < image->info->min_x)
-			image->info->min_x = boundingBox.left;
-		if (boundingBox.right+repeat_off_X > image->info->max_x)
-			image->info->max_x = boundingBox.right+repeat_off_X;
-		if (boundingBox.bottom < image->info->min_y)
-			image->info->min_y = boundingBox.bottom;
-		if (boundingBox.top+repeat_off_Y > image->info->max_y)
-			image->info->max_y = boundingBox.top+repeat_off_Y;
+		gerber_update_image_min_max(&boundingBox, repeat_off_X, repeat_off_Y, image);
+		
 		/* optionally update the knockout measurement box */
 		if (knockoutMeasure) {
 			if (boundingBox.left < knockoutLimitXmin)
@@ -2652,7 +2659,19 @@ gerber_calculate_final_justify_effects(gerbv_image_t *image)
 } /* gerber_calculate_final_justify_effects */
 
 
-static void
+void gerber_update_image_min_max (gerbv_render_size_t *boundingBox, double repeat_off_X,
+		double repeat_off_Y, gerbv_image_t* image) {
+	if (boundingBox->left < image->info->min_x)
+		image->info->min_x = boundingBox->left;
+	if (boundingBox->right+repeat_off_X > image->info->max_x)
+		image->info->max_x = boundingBox->right+repeat_off_X;
+	if (boundingBox->bottom < image->info->min_y)
+		image->info->min_y = boundingBox->bottom;
+	if (boundingBox->top+repeat_off_Y > image->info->max_y)
+		image->info->max_y = boundingBox->top+repeat_off_Y;
+}
+
+void
 gerber_update_min_and_max(gerbv_render_size_t *boundingBox,
 			  gdouble x, gdouble y, gdouble apertureSizeX1,
 			  gdouble apertureSizeX2,gdouble apertureSizeY1,
